@@ -14,9 +14,11 @@ class Utils:
     def convert_timestamp_to_building_timezone(self, building_id: str, timestamp: datetime) -> datetime:
         """
         :param building_id: the building to get the timezone from
-        :param timestamp: no timezone
-        # :return: UTC representation of the timestamp in the building's timezone
+        :return: UTC representation of the timestamp in the building's timezone
+        TODO: Switch from pytz to dateutil
         """
-        building = self.basking.location.get_building(building_id=building_id)
-        timezoned_timestamp = pytz.timezone(building['data']['getBuilding']['timeZone']).localize(timestamp)
-        return datetime.utcfromtimestamp(timezoned_timestamp.timestamp())
+        building_tz = pytz.timezone(
+            self.basking.location.get_building(building_id=building_id)['data']['getBuilding']['timeZone']
+        )
+        tz_conversion = building_tz.normalize if timestamp.tzinfo else building_tz.localize
+        return datetime.utcfromtimestamp(tz_conversion(timestamp).timestamp())
